import EventEmitter from 'EventEmitter';
import Document from './DOM/Document';

import HTMLImageElement from './DOM/HTMLImageElement';
import HTMLCanvasElement from './DOM/HTMLCanvasElement';
import HTMLVideoElement from './DOM/HTMLVideoElement';
import CanvasRenderingContext2D from './API/CanvasRenderingContext2D';

global.HTMLImageElement = global.HTMLImageElement || HTMLImageElement;
global.Image = global.Image || HTMLImageElement;
global.HTMLVideoElement = global.HTMLVideoElement || HTMLVideoElement;
global.Video = global.Video || HTMLVideoElement;
global.HTMLCanvasElement = global.HTMLCanvasElement || HTMLCanvasElement;
global.Canvas = global.Canvas || HTMLCanvasElement;
global.CanvasRenderingContext2D =
  global.CanvasRenderingContext2D || CanvasRenderingContext2D;
global.WebGLRenderingContext = global.WebGLRenderingContext || function() {};

window.performance = window.performance || {
  now: () => ({
    bind: () => () => ({}),
  }),
};

function checkEmitter() {
  if (
    !window.emitter ||
    !(
      window.emitter.on ||
      window.emitter.addEventListener ||
      window.emitter.addListener
    )
  ) {
    window.emitter = new EventEmitter();
  }
}

window.scrollTo = window.scrollTo || (() => ({}));

window.addEventListener = (eventName, listener) => {
  checkEmitter();
  if (window.emitter.on) {
    window.emitter.on(eventName, listener);
  } else if (window.emitter.addEventListener) {
    window.emitter.addEventListener(eventName, listener);
  } else if (window.emitter.addListener) {
    window.emitter.addListener(eventName, listener);
  }
};

window.removeEventListener = (eventName, listener) => {
  checkEmitter();
  if (window.emitter.off) {
    window.emitter.off(eventName, listener);
  } else if (window.emitter.removeEventListener) {
    window.emitter.removeEventListener(eventName, listener);
  } else if (window.emitter.removeListener) {
    window.emitter.removeListener(eventName, listener);
  }
};

window.DOMParser = window.DOMParser || require('xmldom-qsa').DOMParser;

import { TextDecoder, TextEncoder } from 'text-encoding';
global.TextDecoder = global.TextDecoder || TextDecoder;
global.TextEncoder = global.TextEncoder || TextEncoder;

const agent = 'chrome';
global.userAgent = global.userAgent || agent;
global.navigator.userAgent = global.navigator.userAgent || agent;
global.navigator.platform = global.navigator.platform || [];
global.navigator.appVersion = global.navigator.appVersion || 'OS10';
global.navigator.maxTouchPoints = global.navigator.maxTouchPoints || 5;
global.navigator.standalone =
  global.navigator.standalone === null ? true : global.navigator.standalone;

///https://www.w3schools.com/js/js_window_location.asp
window.location = window.location || {
  href: '', //  window.location.href returns the href (URL) of the current page
  hostname: '', //window.location.hostname returns the domain name of the web host
  pathname: '', //window.location.pathname returns the path and filename of the current page
  protocol: 'https', //window.location.protocol returns the web protocol used (http: or https:)
  assign: null, //window.location.assign loads a new document
};
